==> ziplib-0.1.tar.gz: ziplib-0.1/setup.py <==
from distutils.core import setup

setup(
  name = 'ziplib',         # How you named your package folder (MyLib)
  packages = ['ziplib'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Zip a file or directory of files with the option to enable password protection',   # Give a short description about your library
  author = 'Sebastiano Rosolen',                   # Type in your name
  author_email = 'sebastiano.rosolen@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Sebo97/zipme',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Sebo97/ziplib/archive/refs/tags/0.1.tar.gz',    # I explain this later on
  keywords = ['zipfile', 'zip', 'encryption'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'pyminizip',
          'zipfile',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> ziplib-0.1.1.tar.gz: ziplib-0.1.1/setup.py <==
from distutils.core import setup

setup(
  name = 'ziplib',         # How you named your package folder (MyLib)
  packages = ['ziplib'],   # Chose the same as "name"
  version = '0.1.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Zip a file or directory of files with the option to enable password protection',   # Give a short description about your library
  author = 'Sebastiano Rosolen',                   # Type in your name
  author_email = 'sebastiano.rosolen@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Sebo97/zipme',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Sebo97/ziplib/archive/refs/tags/0.1.1.tar.gz',    # I explain this later on
  keywords = ['zipfile', 'zip', 'encryption'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'pyminizip',
          'zipfile',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
